/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.collections.adapters;

import java.util.ArrayList;
import java.util.List;

import org.builtu.collections.adapters.ImmutableListAdapter;
import org.builtu.testing.BasicTestCase;
import org.junit.Before;
import org.junit.Test;


public class TestImmutableListAdapter extends BasicTestCase {
	
	private static interface Immutable {}
	
	private static class Mutable implements Immutable {}
	
	private final List<Mutable> mutables = new ArrayList<Mutable>();
	
	private void check() {
		final List<?> it1 = mutables;
		final List<?> it2 = new ImmutableListAdapter<Immutable, Mutable>(mutables);
		assertListsEquals(it1, it2);
	}
	
	@Before public void clear() {
		mutables.clear();
	}
	
	@Test public void testEmpty() {
		check();
	}
	
	@Test public void testOne() {
		mutables.add(new Mutable());
		check();
	}

	@Test public void testTwo() {
		mutables.add(new Mutable());
		mutables.add(new Mutable());
		check();
	}
	
	@Test public void testThree() {
		mutables.add(new Mutable());
		mutables.add(new Mutable());
		mutables.add(new Mutable());
		check();
	}
	
	@Test public void testFour() {
		mutables.add(new Mutable());
		mutables.add(new Mutable());
		mutables.add(new Mutable());
		mutables.add(new Mutable());
		check();
	}
}
