/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.collections.graph;

import java.util.List;

/**
 * Directed graph immutable interface.
 * @author borisman
 */
public interface Node<E> {
	/**
	 * @return node id of this node
	 */
	String getNodeId();

	/**
	 * @return node value
	 */
	E getValue();
	
	/**
	 * @return node at path (relative to this node)
	 */
	Node<E> path(String path);
	
	/**
	 * @return all parents of this node
	 */
	List<Node<E>> getParents();
	
	/**
	 * @return all children of this node
	 */
	List<Node<E>> getChildren();
	
	/**
	 * Same as getChildren().get(idx)
	 */
	Node<E> get(int idx);

	/**
	 * @return direct child node by it's id 
	 */
	Node<E> get(String id);

	/**
	 * @return true if node has any parents (same as {@link Node#getParents()}.size()&gt;0)
	 */
	boolean hasParents();

	/**
	 * @return true if node has any children (same as {@link Node#getChildren()}.size()&gt;0)
	 */
	boolean hasChildren();
	
	/**
	 * @return first path from root to this node
	 */
	String getFirstPath();
	
	/**
	 * @return all possible paths from root node to this node
	 */
	List<String> getAllPaths();
	
}
