/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.collections.graph;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;

import junit.framework.Assert;

import org.builtu.collections.graph.Node;
import org.junit.Test;


public class TestNodeImplToNodeAdapterSimple extends NodeImplToNodeAdapterTestBase {

	@Test public void testEmpty() {
		Assert.assertSame(0, adapter.size());
	}
	
	@Test public void testOne1() {
		list.add(node1);
		Assert.assertSame(1, adapter.size());
		Assert.assertSame(node1, adapter.get(0));
	}
	
	@Test public void testOne2() {
		list.add(node2);
		Assert.assertSame(1, adapter.size());
		Assert.assertSame(node2, adapter.get(0));
	}

	@Test public void testContains() {
		list.add(node2);
		Assert.assertTrue(adapter.contains(node2));
		Assert.assertFalse(adapter.contains(node1));
	}

	@Test public void testContainsAll() {
		list.add(node2);
		Assert.assertTrue(adapter.containsAll(list));
		Assert.assertTrue(adapter.containsAll(adapter));
		final List<Node<Long>> l2 = new ArrayList<Node<Long>>();
		l2.add(node1);
		l2.add(node2);
		Assert.assertFalse(adapter.containsAll(l2));
	}
	
	@Test public void testIndexOf() {
		list.add(node1);
		list.add(node1);
		list.add(node2);
		list.add(node1);
		Assert.assertEquals(0, adapter.indexOf(node1));
		Assert.assertEquals(2, adapter.indexOf(node2));
		Assert.assertEquals(-1, adapter.indexOf(new Object()));
	}
	
	@Test public void testIsEmpty() {
		Assert.assertTrue(adapter.isEmpty());
		list.add(node1);
		Assert.assertFalse(adapter.isEmpty());
		list.remove(node1);
		Assert.assertTrue(adapter.isEmpty());
	}
	
	@Test public void testIterator1() {
		Assert.assertFalse(adapter.iterator().hasNext());
		Assert.assertFalse(adapter.listIterator().hasNext());
		assertRaisesNoSuchElementException(adapter.iterator());
		assertRaisesNoSuchElementException(adapter.listIterator());
		list.add(node1);
		Assert.assertTrue(adapter.iterator().hasNext());
		Assert.assertTrue(adapter.listIterator().hasNext());
		Assert.assertSame(node1, adapter.iterator().next());
		Assert.assertSame(node1, adapter.listIterator().next());
	}

	private static void assertRaisesNoSuchElementException(final Iterator<Node<Long>> it) {
		try {
			it.next();
			Assert.fail();
		} catch (final NoSuchElementException e) {}
	}
}
