/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.config.spring;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.apache.log4j.Logger;
import org.builtu.exceptions.FatalError;
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;


public class DefaultPropertyPlaceholderConfigurer extends PropertyPlaceholderConfigurer {
	
	private static final Logger log = Logger.getLogger(DefaultPropertyPlaceholderConfigurer.class);
 
	private Map<String, String> startingProperties = new HashMap<String, String>();

	public void setStartingProperties(Map<String, String> startingProperties) {
		this.startingProperties = startingProperties;
		try {
			loadDefaultProperties();
		} catch (final IOException e) {
			throw new FatalError(e);
		}
	}

	private void loadDefaultProperties() throws IOException {
		final Properties defaultProperties = new Properties();
		for (Map.Entry<String, String> entry : startingProperties.entrySet()) {
			defaultProperties.put(entry.getKey(), entry.getValue());
			log.info(entry.getKey()+"="+entry.getValue());
		}
		this.setPropertiesArray(new Properties[] { defaultProperties });
	}
}
