/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.markup;

import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;

import junit.framework.Assert;

import org.builtu.collections.graph.Node;
import org.builtu.markup.Parser;
import org.junit.Test;
import org.xml.sax.SAXException;



public class TestParser {
	
	private static final String XML_HEAD="<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";

	@Test public void testEmptyRootNoHead() throws Exception {
		final Node<String> s = Parser.parseXML("<root/>");
		Assert.assertEquals("root", s.getNodeId());
		Assert.assertSame(null, s.getValue());
	}

	@Test public void testEmptyRootWithHead() throws Exception {
		final Node<String> s = Parser.parseXML(XML_HEAD+"<root/>");
		Assert.assertEquals("root", s.getNodeId());
		Assert.assertSame(null, s.getValue());
	}
	
	@Test public void testRoot() throws Exception {
		final Node<String> s = Parser.parseXML("<root>1</root>");
		Assert.assertEquals("root", s.getNodeId());
		Assert.assertEquals("1", s.getValue());
	}
	
	@Test public void testList() throws Exception {
		final Node<String> s = Parser.parseXML("<roots><root>1</root><root>2</root></roots>");
		Assert.assertSame("roots", s.getNodeId());
		
		Assert.assertEquals("root", s.get(0).getNodeId());
		Assert.assertEquals("1", s.get(0).getValue());
		Assert.assertEquals("root.2", s.get(1).getNodeId());
		Assert.assertEquals("2", s.get(1).getValue());
	}
	
	@Test public void testAttributes() throws Exception {
		final Node<String> s = Parser.parseXML("<root attribute=\"value\"/>", true);
		Assert.assertEquals("root", s.getNodeId());
		Assert.assertEquals("value", s.path("<attributes>/attribute").getValue());
	}
	
	@Test public void testReal() throws Exception {
		final Node<String> s = Parser.parseXML(XML_HEAD+"<response_payments_openDialog>\n"+
										                "<openDialog>1</openDialog>\n"+
										                "</response_payments_openDialog>\n");
		Assert.assertEquals("openDialog", s.path("openDialog").getNodeId());
	}
}
