/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.testing.webmock;

import java.util.HashMap;
import java.util.Map;

import junit.framework.Assert;

import org.builtu.testing.webmock.Request;
import org.junit.Test;


public class TestRequest {
	@Test public void testEmpty() {
		final Request r1 = new Request();
		final Request r2 = new Request();
		
		Assert.assertEquals(r1, r2);
		Assert.assertEquals(r1.hashCode(), r2.hashCode());
	}
	
	@Test public void testOneParam() {
		final Request r1 = new Request();
		final Request r2 = new Request();
		
		r1.params.put("key", new String [] {"value"} );
		
		Assert.assertTrue(!r1.equals(r2));
		Assert.assertTrue(r1.hashCode() != r2.hashCode());
		
		r2.params.put("key", new String [] {"value"} );
		
		Assert.assertEquals(r1, r2);
		Assert.assertEquals(r1.hashCode(), r2.hashCode());
	}
	
	@Test public void testArray() {
		final Request r1 = new Request();
		final Request r2 = new Request();
		
		r1.params.put("key", new String [] {"value1", "value2"} );
		r2.params.put("key", new String [] {"value2", "value1"} );
		
		Assert.assertEquals(r1, r2);
		Assert.assertEquals(r1.hashCode(), r2.hashCode());
	}
	
	@Test(expected=IllegalArgumentException.class) public void testBadPath1() {
		new Request().setPath("/?");
	}
	
	@Test(expected=IllegalArgumentException.class) public void testBadPath2() {
		new Request().setPath("/&");
	}
	
	@Test public void testPath() {
		final Request r1 = new Request();
		final Request r2 = new Request();
		
		r1.setPath("/hello");
		
		Assert.assertTrue(!r1.equals(r2));
		Assert.assertTrue(r1.hashCode() != r2.hashCode());
		
		r2.setPath("/hello");
		
		Assert.assertEquals(r1, r2);
		Assert.assertEquals(r1.hashCode(), r2.hashCode());
	}

	@Test public void testAdd() {
		final Request r1 = new Request();
		r1.add("key", "value");
		Assert.assertEquals("value", r1.params.get("key")[0]);
		r1.add("key", "value2");
		Assert.assertEquals("value2", r1.params.get("key")[1]);
	}
	
	@Test public void testSet() {
		final Request r1 = new Request();
		r1.set("key", "value");
		Assert.assertEquals("value", r1.params.get("key")[0]);
		r1.set("key", "value1", "value2");
		Assert.assertEquals("value1", r1.params.get("key")[0]);
		Assert.assertEquals("value2", r1.params.get("key")[1]);
	}
	
	@Test public void testIgnoredParams() {
		final Request r1 = new Request();
		final Request r2 = new Request();
		
		r1.set("key", "value");
		r2.set("key");
		
		Assert.assertEquals(r1, r2);
		Assert.assertTrue(r1.hashCode() == r2.hashCode());
		
		r2.set("key2", "value2");
		Assert.assertFalse(r1.equals(r2));
		Assert.assertFalse(r1.hashCode() == r2.hashCode());
		
		r1.set("key2");
		Assert.assertEquals(r1, r2);
		Assert.assertTrue(r1.hashCode() == r2.hashCode());
		
		final Map<Request, String> map = new HashMap<Request, String>();
		final String value = "value";
		map.put(r1, value);
		Assert.assertSame(value, map.get(r2));
		map.clear();
		map.put(r2, value);
		Assert.assertSame(value, map.get(r1));
	}
	
}
