/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.util.commutil;

import java.net.InetAddress;
import java.net.UnknownHostException;

public class InetUtil {
	
	private static volatile byte[] ip;
	private static volatile String ipStr, hostname;
	
	public static byte [] getLocalIpAddress () throws UnknownHostException {
		if (ip != null) return ip;
		loadIpAndHost();
		assert ip != null;
		return ip;
	}

	public static String getLocalIpAddressString () throws UnknownHostException {
		if (ipStr != null) return ipStr;
		loadIpAndHost();
		assert ipStr != null;
		return ipStr;
	}

	public static String getLocalHostName() throws UnknownHostException {
		if (hostname != null) return hostname;
		loadIpAndHost();
		assert hostname != null;
		return hostname;
	}
	
	private synchronized static void loadIpAndHost() throws UnknownHostException {
		if (ip != null) return;
		final InetAddress addr = InetAddress.getLocalHost();
		ip = addr.getAddress();
		hostname = addr.getHostName();
		ipStr = addr.getHostAddress();
	}
	
}
